==> apache-beam-2.5.0-source-release.zip: beam-release-2.5.0/sdks/java/core/src/main/java/org/apache/beam/sdk/util/BackOffUtils.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.beam.sdk.util;

import java.io.IOException;

/**
 * Utilities for {@link BackOff}.
 *
 * <p><b>Note</b>: This is copied from Google API client library to avoid its dependency.
 */
public final class BackOffUtils {

  /**
   * Runs the next iteration of the back-off policy, and returns whether to continue to retry the
   * operation.
   *
   * <p>
   * If {@code true}, it will call {@link Sleeper#sleep(long)} with the specified number of
   * milliseconds from {@link BackOff#nextBackOffMillis()}.
   * </p>
   *
   * @param sleeper sleeper
   * @param backOff back-off policy
   * @return whether to continue to back off; in other words, whether
   *         {@link BackOff#nextBackOffMillis()} did not return {@link BackOff#STOP}
   * @throws InterruptedException if any thread has interrupted the current thread
   */
  public static boolean next(Sleeper sleeper, BackOff backOff)
      throws InterruptedException, IOException {
    long backOffTime = backOff.nextBackOffMillis();
    if (backOffTime == BackOff.STOP) {
      return false;
    }
    sleeper.sleep(backOffTime);
    return true;
  }

  private BackOffUtils() {
  }
}

==> apache-beam-2.6.0-source-release.zip: beam-release-2.6.0/sdks/java/core/src/main/java/org/apache/beam/sdk/util/BackOffUtils.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.beam.sdk.util;

import java.io.IOException;

/**
 * Utilities for {@link BackOff}.
 *
 * <p><b>Note</b>: This is copied from Google API client library to avoid its dependency.
 */
public final class BackOffUtils {

  /**
   * Runs the next iteration of the back-off policy, and returns whether to continue to retry the
   * operation.
   *
   * <p>If {@code true}, it will call {@link Sleeper#sleep(long)} with the specified number of
   * milliseconds from {@link BackOff#nextBackOffMillis()}.
   *
   * @param sleeper sleeper
   * @param backOff back-off policy
   * @return whether to continue to back off; in other words, whether {@link
   *     BackOff#nextBackOffMillis()} did not return {@link BackOff#STOP}
   * @throws InterruptedException if any thread has interrupted the current thread
   */
  public static boolean next(Sleeper sleeper, BackOff backOff)
      throws InterruptedException, IOException {
    long backOffTime = backOff.nextBackOffMillis();
    if (backOffTime == BackOff.STOP) {
      return false;
    }
    sleeper.sleep(backOffTime);
    return true;
  }

  private BackOffUtils() {}
}
